powered by
This function allows you to find and search the right country code associated with the Industrial Research and Innovation's Data. If no argument is filed, all indicators will be displayed.
irir_country(country)
The name of the country.
Country's ISO code.
irir_indicator for the IRI's indicators, irir_company for the IRI's companies name, irir_industry for the IRI's industries name and irir_data to collect the data.
irir_indicator
irir_company
irir_industry
irir_data
# NOT RUN { mycountry <- irir_country(country = "Canada") # }
Run the code above in your browser using DataLab