powered by
This function allows you to find and search the right industry name associated with the Industrial Research and Innovation's Data. If no argument is filed, all names will be displayed.
irir_industry(industry)
The name of the industrial sector.
Industry's name.
irir_country for the IRI's country code, irir_indicator for the IRI's indicators, irir_company for the IRI's companies name and irir_data to collect the data.
irir_country
irir_indicator
irir_company
irir_data
# NOT RUN { myindustry <- irir_industry(industry = "Automobile") # }
Run the code above in your browser using DataLab